@@ -38,6 +38,13 @@
 #endif
 
 
+#if defined(__FreeBSD__) || defined(__OpenBSD__) || defined(__NetBSD__)
+#define off64_t off_t
+#define stat64 stat
+#define open64 open
+#endif
+
+
 #define SEL_WIN		0
 #define SEL_SUBWIN	1
 #define SEL_FILES	2
@@ -63,6 +70,10 @@ typedef struct _subwindow_
 	int wfd;	/* write */
 	pid_t pid;
 
+	char *incomplete_line;
+
+	char got_a_lf;
+
 	char *win_title;
 
 	char line_wrap;
