@@ -1,3 +1,4 @@
+#define _LARGEFILE64_SOURCE	/* required for GLIBC to enable stat64 and friends */
 #include <ctype.h>
 #include <errno.h>
 #include <sys/time.h>
@@ -22,6 +23,7 @@ extern int n_colors;
 extern char mail;
 extern char do_refresh;
 extern int max_y, max_x;
+extern char bright_colors;
 
 int term_type = TERM_MISC;
 extern help_t *help;
@@ -473,6 +475,9 @@ WINDOW * mynewwin(int nlines, int ncols, int begin_y, int begin_x)
 	if (!dummy)
 		error_exit("failed to create window (subwin) with dimensions %d-%d at offset %d,%d (terminal size: %d,%d)\n", ncols, nlines, begin_x, begin_y, COLS, LINES);
 
+	if (bright_colors)
+		wattron(dummy, A_BOLD);
+
 	return dummy;
 }
 
