@@ -1,3 +1,4 @@
+#define _LARGEFILE64_SOURCE	/* required for GLIBC to enable stat64 and friends */
 #include <curses.h>
 #include <errno.h>
 #include <signal.h>
@@ -18,9 +19,7 @@
 
 #include "version.h"
 #include "error.h"
-#ifdef _DEBUG
 #include "mt.h"
-#endif
 
 extern int path_max;
 
@@ -107,7 +106,10 @@ void myfree(void *p)
 void * myrealloc(void *oldp, int newsize, char *what)
 {
 #ifdef _DEBUG
-	void *dummy = realloc(oldp, newsize);
+	void *dummy;
+
+	LOG("myrealloc(%s): %d/%d\n", what, oldp, newsize);
+	dummy = realloc(oldp, newsize);
 	if (!dummy)
 		error_exit("failed to reallocate to %d bytes for %s\n", newsize, what);
 	remove_mem_element(oldp);
@@ -409,11 +411,11 @@ int find_char_offset(char *str, char what)
 	return -1;
 }
 
-int file_info(char *filename, off_t *file_size, time_t *ts)
+int file_info(char *filename, off64_t *file_size, time_t *ts)
 {
-	struct stat buf;
+	struct stat64 buf;
 
-	if (stat(filename, &buf) == -1)
+	if (stat64(filename, &buf) == -1)
 	{
 		if (errno != ENOENT)
 			error_exit("error while doing stat() on file %s\n", filename);
@@ -518,7 +520,7 @@ int myopen(char *path, int mode)
 
 	for(;;)
 	{
-		fd = open(path, mode);
+		fd = open64(path, mode);
 		if (fd == -1)
 		{
 			if (errno == EINTR)
